# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import bs4 as BeautifulSoup

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = "seadrive-"
app_name = "SeaDrive"


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob("*%s*.dmg" % bin_contains)[0]

    # Installing the software
    print("Installing: %s" % bin_name)
    install_dmg(bin_name)


def uninstall():
    # Uninstalling the software
    uninstall_app(app_name)


def update_package():
    # Declaring local variables
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    url = "https://www.seafile.com/en/download/"

    # Getting latest version from official website
    for bs_search in bs_find_all(url, "a", "class", "download-op", proxies=proxies):
        latest_bin = bs_search["href"].split("/")[-1]
        if latest_bin.startswith(bin_contains) and latest_bin.endswith(".dmg"):
            url_dl = bs_search["href"]
            version = bs_search.string
            break

    print("Latest %s version is: %s" % (app_name, version))
    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(url_dl, latest_bin, proxies=proxies)

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    control.version = "%s-%s" % (Version(version), control.version.split("-", 1)[-1])
    # control.set_software_version(Version(version))
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating or not update-package-sources
    return result
